% Get first order harmonics
% INPUT:  theta = polar coordinate (0 to pi)
%         phi = azimuthal coordinate (0 to 2*pi)
% OUTPUT:  Ylm = 3 x 1 vector of scalar harmonics (20, 21, 2-1, 22, 2-2)
%          Psi_lm = 3 x 3 vector of vector harmonics grad(Ylm)
%          Phi_lm = 3 x 3 vector of vector harmonics r x grad(Ylm)
function [Ylm, Psi_lm, Phi_lm] = get_1st_ord_harmonics(theta, phi)

% First, define unit vectors
r_hat = [sin(theta) * cos(phi), sin(theta) * sin(phi), cos(theta)];
theta_hat = [cos(theta) * cos(phi), cos(theta) * sin(phi), -sin(theta)];
phi_hat = [-sin(phi), cos(phi), 0];
        
% Zero quantities
Ylm = zeros(3,1);
Psi_lm = zeros(3, 3);
Phi_lm = zeros(3, 3);

% Define harmonic functions
% Y10
Ylm(1) = sqrt(3/(4*pi)) * cos(theta);
Psi_lm(1, :) = -sqrt(3/(4*pi)) * sin(theta) * theta_hat;

% Y11
Ylm(2) = -sqrt(3/(4*pi)) * sin(theta) * cos(phi);
Psi_lm(2, :) = -sqrt(3/(4*pi)) * ( cos(theta) * cos(phi) * theta_hat - sin(phi) * phi_hat );        

% Y1-1
Ylm(3) = -sqrt(3/(4*pi)) * sin(theta) * sin(phi);
Psi_lm(3, :) = -sqrt(3/(4*pi)) * ( cos(theta) * sin(phi) * theta_hat + cos(phi) * phi_hat );        


% Get Phi_lm
for i = 1:3
    Phi_lm(i, :) = cross(r_hat, Psi_lm(i, :));
end

end