function [nodes, weights] = get_Gaussian_quad_weights(N)

% Perform method described by Golub:
% https://web.stanford.edu/class/cme335/S0025-5718-69-99647-1.pdf
% See http://www2.math.umd.edu/~mariakc/teaching/gaussian.pdf as well

% Get recurrance relation for Legendre polynomials
% Pj = (aj * x + bj) * Pj-1 - cj * Pj-2
a = zeros(N,1);
b = zeros(N,1);
c = zeros(N,1);
for i = 1:N
    a(i) = (2*i-1)/i;
    b(i) = 0;
    c(i) = (i-1)/i;
end

% Perform similarity transformation so that
% xP = mat * P
alpha = zeros(N,1);
beta = zeros(N-1,1);
for i = 1:N
    alpha(i) = -b(i)/a(i);
    if( i ~= N)
        beta(i) = sqrt( c(i+1)/(a(i) * a(i+1)) );
    end
end

% Form matrix and get nodes/weights
mat = diag(alpha) + diag(beta, 1) + diag(beta, -1);
[eigvec, eigvals] = eig(mat);
nodes = diag(eigvals);
weights = (eigvec(1, :)').^2 * 2;

end