% Get second order harmonics
% INPUT:  theta = polar coordinate (0 to pi)
%         phi = azimuthal coordinate (0 to 2*pi)
% OUTPUT:  Ylm = 5 x 1 vector of scalar harmonics (20, 21, 2-1, 22, 2-2)
%          Psi_lm = 5 x 3 vector of vector harmonics grad(Ylm)
%          Phi_lm = 5 x 3 vector of vector harmonics r x grad(Ylm)
function [Ylm, Psi_lm, Phi_lm] = get_2nd_ord_harmonics(theta, phi)

% First, define unit vectors
r_hat = [sin(theta) * cos(phi), sin(theta) * sin(phi), cos(theta)];
theta_hat = [cos(theta) * cos(phi), cos(theta) * sin(phi), -sin(theta)];
phi_hat = [-sin(phi), cos(phi), 0];
        
% Zero quantities
Ylm = zeros(5,1);
Psi_lm = zeros(5, 3);
Phi_lm = zeros(5, 3);


% Define harmonic functions
% Y20
Ylm(1) = 1/4 * sqrt(5/pi) * (3 * cos(theta)^2 - 1);
Psi_lm(1, :) = -3/4 * sqrt(5/pi) * sin(2*theta) * theta_hat;

% Y21
Ylm(2) = -sqrt(15/(4*pi)) * sin(theta) * cos(theta) * cos(phi);
Psi_lm(2, :) = sqrt(15/(4*pi)) * ( -cos(2*theta) * cos(phi) * theta_hat + cos(theta) * sin(phi) * phi_hat );        

% Y2-1
Ylm(3) = -sqrt(15/(4*pi)) * sin(theta) * cos(theta) * sin(phi);        
Psi_lm(3, :) = sqrt(15/(4*pi)) * ( -cos(2*theta) * sin(phi) * theta_hat - cos(theta) * cos(phi) * phi_hat );

% Y22
Ylm(4) = 1/4 * sqrt(15/pi) * sin(theta)^2 * cos(2*phi);
Psi_lm(4, :) = 1/4 * sqrt(15/pi) * ( sin(2*theta) * cos(2*phi) * theta_hat - 2 * sin(theta) * sin(2*phi) * phi_hat );
        
% Y2-2
Ylm(5) = 1/4 * sqrt(15/pi) * sin(theta)^2 * sin(2*phi);
Psi_lm(5, :) = 1/4 * sqrt(15/pi) * ( sin(2*theta) * sin(2*phi) * theta_hat + 2 * sin(theta) * cos(2*phi) * phi_hat );


% Get Phi_lm
for i = 1:5
    Phi_lm(i, :) = cross(r_hat, Psi_lm(i, :));
end

end